@@ -8,11 +8,13 @@ parse than existing "memo-like" formats (memo, youbeat, etc ...).
 https://github.com/Stepland/memon
 """
 
-from .memon import (
+from .v0 import (
     dump_memon_0_1_0,
     dump_memon_0_2_0,
+    dump_memon_0_3_0,
     dump_memon_legacy,
     load_memon_0_1_0,
     load_memon_0_2_0,
+    load_memon_0_3_0,
     load_memon_legacy,
 )
