@@ -1,36 +1,12 @@
-import tempfile
-from pathlib import Path
 from typing import Set
 
 import hypothesis.strategies as st
 from hypothesis import given
 
 from jubeatools import song
-from jubeatools.formats.typing import Dumper, Loader
+from jubeatools.formats.enum import Format
 from jubeatools.testutils import strategies as jbst
-
-from . import (
-    dump_memon_0_1_0,
-    dump_memon_0_2_0,
-    dump_memon_legacy,
-    load_memon_0_1_0,
-    load_memon_0_2_0,
-    load_memon_legacy,
-)
-
-
-def dump_and_load(
-    expected_song: song.Song, dump_function: Dumper, load_function: Loader
-) -> None:
-    with tempfile.NamedTemporaryFile(mode="wb") as file:
-        files = dump_function(expected_song, Path(file.name))
-        assert len(files) == 1
-        filename, contents = list(files.items())[0]
-        file.write(contents)
-        file.seek(0)
-        actual_song = load_function(Path(file.name))
-
-    assert actual_song == expected_song
+from jubeatools.testutils.test_patterns import dump_and_load_then_compare
 
 
 @st.composite
@@ -56,6 +32,11 @@ def memon_legacy_compatible_song(draw: st.DrawFn) -> song.Song:
             diffs_strat=memon_diffs(),
             chart_strat=jbst.chart(timing_strat=st.none()),
             common_timing_strat=jbst.timing_info(with_bpm_changes=False),
+            metadata_strat=jbst.metadata(
+                text_strat=st.text(
+                    alphabet=st.characters(blacklist_categories=("Cc", "Cs")),
+                ),
+            ),
         )
     )
     random_song.metadata.preview = None
@@ -65,7 +46,7 @@ def memon_legacy_compatible_song(draw: st.DrawFn) -> song.Song:
 
 @given(memon_legacy_compatible_song())
 def test_memon_legacy(song: song.Song) -> None:
-    dump_and_load(song, dump_memon_legacy, load_memon_legacy)
+    dump_and_load_then_compare(Format.MEMON_LEGACY, song)
 
 
 memon_0_1_0_compatible_song = memon_legacy_compatible_song
@@ -73,7 +54,7 @@ memon_0_1_0_compatible_song = memon_legacy_compatible_song
 
 @given(memon_0_1_0_compatible_song())
 def test_memon_0_1_0(song: song.Song) -> None:
-    dump_and_load(song, dump_memon_0_1_0, load_memon_0_1_0)
+    dump_and_load_then_compare(Format.MEMON_0_1_0, song)
 
 
 @st.composite
@@ -84,6 +65,11 @@ def memon_0_2_0_compatible_song(draw: st.DrawFn) -> song.Song:
             diffs_strat=memon_diffs(),
             chart_strat=jbst.chart(timing_strat=st.none()),
             common_timing_strat=jbst.timing_info(with_bpm_changes=False),
+            metadata_strat=jbst.metadata(
+                text_strat=st.text(
+                    alphabet=st.characters(blacklist_categories=("Cc", "Cs")),
+                ),
+            ),
         )
     )
     random_song.metadata.preview_file = None
@@ -92,4 +78,25 @@ def memon_0_2_0_compatible_song(draw: st.DrawFn) -> song.Song:
 
 @given(memon_0_2_0_compatible_song())
 def test_memon_0_2_0(song: song.Song) -> None:
-    dump_and_load(song, dump_memon_0_2_0, load_memon_0_2_0)
+    dump_and_load_then_compare(Format.MEMON_0_2_0, song)
+
+
+@st.composite
+def memon_0_3_0_compatible_song(draw: st.DrawFn) -> song.Song:
+    return draw(
+        jbst.song(
+            diffs_strat=memon_diffs(),
+            chart_strat=jbst.chart(timing_strat=st.none()),
+            common_timing_strat=jbst.timing_info(with_bpm_changes=False),
+            metadata_strat=jbst.metadata(
+                text_strat=st.text(
+                    alphabet=st.characters(blacklist_categories=("Cc", "Cs")),
+                ),
+            ),
+        )
+    )
+
+
+@given(memon_0_3_0_compatible_song())
+def test_memon_0_3_0(song: song.Song) -> None:
+    dump_and_load_then_compare(Format.MEMON_0_3_0, song)
